def readlines(filepath: str):
    """
    Easy way to get list of lines of the file given
    """
    with open(filepath, "r") as f:
        lines = f.readlines()
    return lines


def read(filepath: str):
    """
    Easy way to get data of the file given
    """
    with open(filepath, "r") as f:
        data = f.read()
    return data


def write(filepath: str, data: str):
    """
    Easy way to write the data of the file given
    """
    with open(filepath, "w") as f:
        f.write(data)


def append(filepath: str, data: str):
    """
    Easy way to append data the file given
    """
    with open(filepath, "a") as f:
        f.write(data)



import json


def read_json(filepath):
    """
    Reads a json file, and returns the data
    """
    with open(filepath, "r") as f:
        data = json.load(f)
    return data


def write_json(filepath, data):
    """
    Writes a json file with the given data, or creates one if it doesn't exist
    """
    with open(filepath, "w") as f:
        json.dump(data, f)


def get_json_key(filepath, keyname):
    """
    Gets a json file key
    """
    with open(filepath, "r") as f:
        data = json.load(f)
    return data[keyname]


def get_key(filepath, keyname):
    """
    An alias for -
    ```py
    fileops.jsonops.get_json_key()
    ```
    """
    return get_json_key(filepath, keyname)



import setuptools
import os

here = os.path.abspath(os.path.dirname(__file__))

VERSION = "0.0.2"
DESCRIPTION = "Do simple operations for files easier"
with open("README.md", "r", encoding="utf-8") as fh:
    LONG_DESCRIPTION = fh.read()

setuptools.setup(
    name="simple-file-ops",
    version=VERSION,
    author="Cube Riser",
    author_email="cuberiser@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=setuptools.find_packages(),
    install_requires=[''],
    keywords=["python", "file operations", "files", "fileops", "file-operations"],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    license='MIT'
)
